elvis_config (elvis_core v5.0.3)
View SourceSummary
Functions
Takes a function and configuration and applies the function to all file in the configuration.
Merge user rules (override) with elvis default rules.
Takes a configuration and finds all files according to its 'files' globs.
Takes a configuration and a list of files, filtering some of them according to the 'files' globs and ignore list.
Types
Functions
Takes a function and configuration and applies the function to all file in the configuration.
-spec default() -> [t()].
-spec files(RuleGroup :: [t()] | t()) -> [elvis_file:t()].
-spec merge_rules(UserRules :: list(), DefaultRules :: list()) -> [elvis_rule:t()].
Merge user rules (override) with elvis default rules.
-spec output_format() -> output_format() | {error, Message :: string()}.
-spec parallel() -> pos_integer() | {error, Message :: string()}.
Takes a configuration and finds all files according to its 'files' globs.
-spec resolve_files(Config :: [t()] | t(), Files :: [elvis_file:t()]) -> [t()] | t().
Takes a configuration and a list of files, filtering some of them according to the 'files' globs and ignore list.
-spec rules(RulesL :: [t()]) -> [[elvis_rule:t()]]; (Rules :: t()) -> [elvis_rule:t()].
-spec set_no_output(boolean()) -> ok.
-spec set_output_format(output_format()) -> ok.
-spec set_parallel(pos_integer()) -> ok.
-spec set_verbose(boolean()) -> ok.
-spec set_warnings_as_errors(boolean()) -> ok.