elvis_text_style (elvis_core v5.0.3)
View SourceSummary
Functions
File can be either a filename or the name of a module.
Functions
-spec default(RuleName :: atom()) -> elvis_rule:def().
-spec max_line_length(elvis_rule:t(), elvis_config:t()) -> [elvis_result:item()].
File can be either a filename or the name of a module.
-spec no_redundant_blank_lines(elvis_rule:t(), elvis_config:t()) -> [elvis_result:item()].
-spec no_tabs(elvis_rule:t(), elvis_config:t()) -> [elvis_result:item()].
-spec no_trailing_whitespace(elvis_rule:t(), elvis_config:t()) -> [elvis_result:item()].