No Author

The use of attribute -author(_) should be avoided.

Avoid

-author("john.doe@ericsson.com").

Prefer

% nothing to replace it with

Rationale

In modern Erlang, this practice serves no specific purpose.

Reference

Paraphrasing @aboroska...:

the custom of adding an author attribute came from Ericsson with the intention to help operations/testers to call/notify the right developers when a crash happened.

Options

  • None.

Example configuration

{elvis_style, no_author, #{}}