elvis_file (elvis_core v5.0.3)
View SourceSummary
Functions
Returns the file encoding.
Filter files to those matching the globs and not matching any ignore regex.
Returns all files matching the given glob patterns.
Loads and adds all related file data.
Return module name corresponding to a given .hrl/.erl/.beam file
Add the root node of the parse tree to the file data, with filtering.
Given a t() returns its path.
Returns a tuple with the contents of the file and the file itself.
Types
Functions
Returns the file encoding.
Filter files to those matching the globs and not matching any ignore regex.
Returns all files matching the given glob patterns.
-spec get_abstract_parse_tree(t()) -> ktn_code:tree_node().
-spec load_file_data([elvis_config:t()] | elvis_config:t(), t()) -> t().
Loads and adds all related file data.
Return module name corresponding to a given .hrl/.erl/.beam file
-spec parse_tree(elvis_rule:t() | elvis_file:t(), [elvis_config:t()] | elvis_config:t()) -> {ktn_code:tree_node(), t()}.
Add the root node of the parse tree to the file data, with filtering.
Given a t() returns its path.
Returns a tuple with the contents of the file and the file itself.